==> ktorrent-5.0.1.tar.xz: ktorrent-5.0.1/ktorrent/view/viewselectionmodel.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef KTVIEWSELECTIONMODEL_H
#define KTVIEWSELECTIONMODEL_H

#include <QSet>
#include <util/itemselectionmodel.h>

namespace bt
{
}

namespace kt
{
    class ViewModel;

    /**
        Custom selection model for View
    */
    class ViewSelectionModel : public ItemSelectionModel
    {
        Q_OBJECT
    public:
        ViewSelectionModel(ViewModel* vm, QObject* parent);
        virtual ~ViewSelectionModel();
    };

}

#endif

==> ktorrent_5.1.1.orig.tar.xz: ktorrent-5.1.1/ktorrent/view/viewselectionmodel.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KTVIEWSELECTIONMODEL_H
#define KTVIEWSELECTIONMODEL_H

#include <util/itemselectionmodel.h>

namespace bt
{
}

namespace kt
{
    class ViewModel;

    /**
        Custom selection model for View
    */
    class ViewSelectionModel : public ItemSelectionModel
    {
        Q_OBJECT
    public:
        ViewSelectionModel(ViewModel* vm, QObject* parent);
        ~ViewSelectionModel();
    };

}

#endif
